@@ -1,6 +1,7 @@
 inkei <- function(length=35, squirt=4, thickness=4)
 {
-   if (thickness > 3){
+   if (thickness <= 3){thickness=4}
+   
       cat("          ", rep("_", length), "\n", sep="")
       
       for (t in 1:floor(thickness/2))
@@ -12,7 +13,7 @@ inkei <- function(length=35, squirt=4, thickness=4)
       {
          cat("          ", rep(" ", length+floor(thickness/2)-t+1), "/\n", sep="")
       }
-   }
+   
    cat("          ", rep("_", length+1), "/\n", sep="")
    cat("          \\
   .... |...|
