@@ -13,7 +13,7 @@ newhatB<-function(Z=Z,A=A,Atilde=Atilde,Bold=B,intercept=TRUE){
    for(j in I2){
       if(as.numeric(A[j+intercept])!=0){#si A2 est nul,  on ne peut utiliser la formule et donc on garde Bold
          I1loc=c(1,which(Z[,j]!=0)+1)
-         if(sum(Atilde[I1loc]!=A[I1loc])!=0){#A et Atilde sont gaux donc A2 est nul, on ne peut utiliser la formule et donc on garde Bold
+         if(sum(Atilde[I1loc]!=A[I1loc])!=0){#A et Atilde sont egaux donc A2 est nul, on ne peut utiliser la formule et donc on garde Bold
             B[I1loc,j]=(Atilde[I1loc]-A[I1loc])/as.numeric(A[j+intercept])             
             #print("calcul effectif")
          }
